==> salt-0.9.9.1.tar.gz: salt-0.9.9.1/salt/exceptions.py <==
'''
This module is a central location for all salt exceptions
'''

class SaltException(Exception):
    '''
    Base exception class; all Salt-specific exceptions should subclass this
    '''
    pass

class SaltClientError(SaltException):
    '''
    Problem reading the master root key
    '''
    pass

class SaltMasterError(SaltException):
    '''
    Problem reading the master root key
    '''
    pass

class AuthenticationError(SaltException):
    '''
    If sha256 signature fails during decryption
    '''
    pass

class CommandNotFoundError(SaltException):
    '''
    Used in modules or grains when a required binary is not available
    '''
    pass

class CommandExecutionError(SaltException):
    '''
    Used when a module runs a command which returns an error and wants
    to show the user the output gracefully instead of dying
    '''
    pass

class LoaderError(SaltException):
    '''
    Problems loading the right renderer
    '''
    pass

class MinionError(SaltException):
    '''
    Minion problems reading uris such as salt:// or http://
    '''
    pass

class SaltInvocationError(SaltException):
    '''
    Used when the wrong number of arguments are sent to modules or invalid
    arguments are specified on the command line
    '''
    pass

class PkgParseError(SaltException):
    '''
    Used when of the pkg modules cannot correctly parse the output from
    the CLI tool (pacman, yum, apt, aptitude, etc)
    '''
    pass

class SaltRenderError(SaltException):
    '''
    Used when a renderer needs to raise an explicit error
    '''
    pass

==> salt-0.10.2.tar.gz: salt-0.10.2/salt/exceptions.py <==
'''
This module is a central location for all salt exceptions
'''


class SaltException(Exception):
    '''
    Base exception class; all Salt-specific exceptions should subclass this
    '''


class SaltClientError(SaltException):
    '''
    Problem reading the master root key
    '''


class SaltMasterError(SaltException):
    '''
    Problem reading the master root key
    '''


class AuthenticationError(SaltException):
    '''
    If sha256 signature fails during decryption
    '''


class CommandNotFoundError(SaltException):
    '''
    Used in modules or grains when a required binary is not available
    '''


class CommandExecutionError(SaltException):
    '''
    Used when a module runs a command which returns an error and wants
    to show the user the output gracefully instead of dying
    '''


class LoaderError(SaltException):
    '''
    Problems loading the right renderer
    '''


class MinionError(SaltException):
    '''
    Minion problems reading uris such as salt:// or http://
    '''


class SaltInvocationError(SaltException):
    '''
    Used when the wrong number of arguments are sent to modules or invalid
    arguments are specified on the command line
    '''


class PkgParseError(SaltException):
    '''
    Used when of the pkg modules cannot correctly parse the output from
    the CLI tool (pacman, yum, apt, aptitude, etc)
    '''


class SaltRenderError(SaltException):
    '''
    Used when a renderer needs to raise an explicit error
    '''

class SaltReqTimeoutError(SaltException):
    '''
    Thrown when a salt master request call fails to return within the timeout
    '''
